@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Systemd
 #
-# This software is Copyright (c) 2015-2016 by Dominique Dumont.
+# This software is Copyright (c) 2015-2018 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -35,18 +35,17 @@
         }
       }
     ],
+    'generated_by' => 'parse-man.pl from systemd doc',
     'include' => [
       'Systemd::CommonElements'
     ],
     'name' => 'Systemd::Service',
-    'read_config' => [
-      {
-        'auto_create' => '1',
-        'auto_delete' => '1',
-        'backend' => 'Systemd::Unit',
-        'file' => '&index.service'
-      }
-    ]
+    'rw_config' => {
+      'auto_create' => '1',
+      'auto_delete' => '1',
+      'backend' => 'Systemd::Unit',
+      'file' => '&index.service'
+    }
   }
 ]
 ;
