@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Systemd
 #
-# This software is Copyright (c) 2015-2017 by Dominique Dumont.
+# This software is Copyright (c) 2015-2018 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -40,14 +40,12 @@
       'Systemd::CommonElements'
     ],
     'name' => 'Systemd::Socket',
-    'read_config' => [
-      {
-        'auto_create' => '1',
-        'auto_delete' => '1',
-        'backend' => 'Systemd::Unit',
-        'file' => '&index.socket'
-      }
-    ]
+    'rw_config' => {
+      'auto_create' => '1',
+      'auto_delete' => '1',
+      'backend' => 'Systemd::Unit',
+      'file' => '&index.socket'
+    }
   }
 ]
 ;
