@@ -1,7 +1,7 @@
 #
 # This file is part of Config-Model-Systemd
 #
-# This software is Copyright (c) 2015-2016 by Dominique Dumont.
+# This software is Copyright (c) 2015-2018 by Dominique Dumont.
 #
 # This is free software, licensed under:
 #
@@ -11,11 +11,13 @@
 
 $home_for_test='/home/joe';
 $conf_dir = '~/.config/systemd/user/';
+$config_file_name = 'systemd-user';
 
 # list of tests. This modules looks for @tests global variable
 @tests = (
     {
         name => 'basic-service',
+        backend_arg => 'gmail',
         file_contents_unlike => {
             "home/joe/.config/systemd/user/gmail-imap-tunnel@.service" 
             => qr/disable/ ,
@@ -24,6 +26,7 @@ $conf_dir = '~/.config/systemd/user/';
 
     {
         name => 'basic-socket',
+        backend_arg => 'gmail',
         file_contents_unlike => {
             "home/joe/.config/systemd/user/gmail-imap-tunnel.socket" 
             => qr/disable/ ,
@@ -32,6 +35,7 @@ $conf_dir = '~/.config/systemd/user/';
 
     {
         name => 'override-service',
+        backend_arg => 'obex',
         setup => {
             'main-obex' => '/usr/lib/systemd/user/obex.service',
             'user-obex' => '~/.config/systemd/user/obex.service',
@@ -50,6 +54,7 @@ $conf_dir = '~/.config/systemd/user/';
     },
     {
         name => 'delete-service',
+        backend_arg => 'obex.service',
         setup => {
             'main-obex' => '/usr/lib/systemd/user/obex.service',
             'user-obex' => '~/.config/systemd/user/obex.service',
@@ -70,6 +75,7 @@ $conf_dir = '~/.config/systemd/user/';
 
     {
         name => 'from-scratch',
+        backend_arg => 'test.service',
         load => 'service:test Unit Description="test from scratch"',
         file_contents_like => {
             "home/joe/.config/systemd/user/test.service" => qr/from scratch/ ,
